@@ -1,6 +1,6 @@
 //
 //	srecord - manipulate eprom load files
-//	Copyright (C) 1998-2004 Peter Miller;
+//	Copyright (C) 1998-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,16 @@ public:
     // See base class for documentation.
     virtual const string filename_and_line() const;
 
+    // See base class for documentation.
+    void disable_checksum_validation();
+
+    /**
+      * The ignore_all_checksums method is used to set the global
+      * ignore checksums flag.  This is usually the result of an
+      * --ignore-checksums command line option.
+      */
+    static void ignore_all_checksums() { ignore_checksums_default = true; }
+
 protected:
     /**
       * The constructor.  The input will be taken from the named file
@@ -60,7 +70,7 @@ protected:
 
     /**
       * The get_char method is used to fetch a character from
-      * the input.	Usually, this is sufficient, however derived
+      * the input.  Usually, this is sufficient, however derived
       * classes may over-ride it if they have a special case.
       * Over-ride with caution, as it affects many other methods.
       *
@@ -72,8 +82,8 @@ protected:
 
     /**
       * The get_char_undo method is used to return a character to
-      * the iinput.  (a later get_char or peak_char method will see
-      * it again).	Only one character may be pushed back.
+      * the input.  (a later get_char or peak_char method will see
+      * it again).  Only one character may be pushed back.
       */
     virtual void get_char_undo(int);
 
@@ -86,8 +96,8 @@ protected:
 
     /**
       * The get_nibble method is used to fetch one hexadecimal digit
-      * fromthe input, via the get_char method.  It is not case
-      * sensitive.	It returns a value for 0 to 15.  Characters which
+      * from the input, via the get_char method.  It is not case
+      * sensitive.  It returns a value for 0 to 15.  Characters which
       * are not hexadecimal digits will result in a fatal error,
       * and the method call will not return.
       */
@@ -102,7 +112,7 @@ protected:
       * The value of the byte will be added to the running checksum,
       * via the checksum_add method.
       *
-      * Usually, this get_byte method implemnation is sufficient for
+      * Usually, this get_byte method implementation is sufficient for
       * most input classes, however derived classes may over-ride
       * it if they have a special case.  Over-ride with caution,
       * as it affects many other methods.
@@ -118,7 +128,7 @@ protected:
 
     /**
       * The get_3bytes method is used to fetch a 24-bit value from
-      * the input.	The get_byte method is called three times,
+      * the input.  The get_byte method is called three times,
       * and the three byte values are assembles big-endian (most
       * significant byte first).
       */
@@ -126,7 +136,7 @@ protected:
 
     /**
       * The get_4bytes method is used to fetch a 32-bit value from
-      * the input.	The get_byte method is called four times,
+      * the input.  The get_byte method is called four times,
       * and the three byte values are assembles big-endian (most
       * significant byte first).
       */
@@ -167,7 +177,7 @@ protected:
     void seek_to_end();
 
     /**
-      * The mode method is used to reyurn a suitable mode string for
+      * The mode method is used to return a suitable mode string for
       * an fopen call.  The default implementation is "r", assuming
       * a text file.  Other file formats may need to override this
       * if they have other needs (e.g. "rb" for binary).
@@ -178,7 +188,7 @@ private:
     /**
       * The file_name instance variable is used by the filename
       * and filename_and_line methods to report the name of the
-      * input file.  This makes for informative error mesages.
+      * input file.  This makes for informative error messages.
       */
     string file_name;
 
@@ -196,13 +206,13 @@ private:
       * the first character after a newline.  In this way, the error
       * messages refer to the correct line, when if (when) it was
       * the the error message must be issued only when the whole
-      * line has ben read in, including the newline.  error message.
+      * line has bean read in, including the newline.  error message.
       */
     bool prev_was_newline;
 
     /**
       * The vfp instance variable is used by the get_fp method to
-      * remember the file pointer.	You need to cast it to FILE* befor
+      * remember the file pointer.  You need to cast it to FILE* before
       * you use it.  Never access this instance variable directly,
       * always go via the get_fp method.  This ensures the file has
       * been opened first!
@@ -213,30 +223,52 @@ protected:
     /**
       * The checksum instance variable is used record the running
       * checksum.  NEVER access this variable directly.  Always use
-      * the checksum_reset method to set it mack to its initial state.
+      * the checksum_reset() method to set it mack to its initial state.
       * Always use the checksum_add method to add a byte to it.
-      * Always use the checksum)_get or checksum_get16 methods to
+      * Always use the checksum_get() or checksum_get16() methods to
       * read its value.
       */
     int checksum;
 
+    /**
+      * The use_checksums method is used to determine whether or not to
+      * validate checksums when data is read.
+      *
+      * @returns
+      *     bool; true if need to check checksums, false to ignore checksums.
+      */
+    bool use_checksums() const { return !ignore_checksums; }
+
 private:
     /**
       * The is_text instance variable is used remember if a file mode
       * is text (true) or binary (false).  This information is  used
       * by the get_char method to decide to increment the line number
       * or not, and by the filename_and_line method to decide whether
-      * or not to include the line number in the location recported.
+      * or not to include the line number in the location reported.
       *
-      * This instance variable is set byu the get_fp method when it
+      * This instance variable is set by the get_fp method when it
       * opens the file.
       */
     int is_text;
 
+    /**
+      * The ignore_checksums instance variable is used to remember
+      * whether or not checksums should be ignored (true) or validated
+      * (false).
+      */
+    bool ignore_checksums;
+
+    /**
+      * The ignore_checksums_default class variable is used to remember
+      * the default checksum validation.  Defaults to false.
+      */
+    static bool ignore_checksums_default;
+
     /**
       * The get_fp method is used to get the stdio file pointer
       * associated with this input file.  (By avoiding a FILE*
-      * declaraion, we avoid habing to include <stdio.h> for not
+      * declaration, we avoid having to include <stdio.h> for no
       * particularly good reason.  Take care when casting.)
       *
       * If the file has not been opened yet, it will be opened by
